@@ -8,7 +8,7 @@ def django_sso_app_context(request):
         "sso_cookie_domain": app_settings.JWT_COOKIE_NAME,
 
         "APP_DOMAIN": settings.APP_DOMAIN,
-        "COOKIE_DOMAIN": settings.COOKIE_DOMAIN,
+        "COOKIE_DOMAIN": app_settings.COOKIE_DOMAIN,
         "I18N_PATH_ENABLED": settings.I18N_PATH_ENABLED,
 
         "DJANGO_SSO_APP_BACKEND_ENABLED": app_settings.BACKEND_ENABLED,
